@@ -1,3 +1,5 @@
+from __future__ import with_statement
+
 # Copyright (c) 2008-2012 Simplistix Ltd
 #
 # This Software is released under the MIT License:
@@ -7,9 +9,9 @@
 from mock import Mock
 from StringIO import StringIO
 from tempfile import TemporaryFile
-from testfixtures import compare,Comparison as C,should_raise,replace,log_capture,tempdir
+from testfixtures import compare, Comparison as C, replace, log_capture, ShouldRaise, tempdir
 from unittest import TestSuite,TestCase,makeSuite
-from xlrd import open_workbook,XL_CELL_NUMBER,XL_CELL_ERROR,XL_CELL_TEXT,XL_CELL_BOOLEAN
+from xlrd import open_workbook, XL_CELL_NUMBER, XL_CELL_ERROR, XL_CELL_BOOLEAN
 from xlrd.formatting import XF
 from xlutils.filter import BaseReader,GlobReader,MethodFilter,BaseWriter,process,XLRDReader,XLWTWriter, BaseFilter
 from xlutils.tests.fixtures import test_files,test_xls_path,make_book,make_sheet,DummyBook
@@ -46,7 +48,8 @@ class TestBaseReader(TestCase):
     def test_no_implementation(self):
         r = BaseReader()
         f = Mock()
-        should_raise(r,NotImplementedError())(f)
+        with ShouldRaise(NotImplementedError()):
+            r(f)
         self.assertEqual(f.method_calls,[('start',(),{})])
         
     def test_ragged_rows(self):
@@ -357,9 +360,8 @@ class TestMethodFilter(TestCase):
             ])
 
     def test_invalid(self):
-        s = should_raise(OurMethodFilter)
-        f = s(self.called,['foo'])
-        compare(s.raised,C(ValueError("'foo' is not a valid method name")))
+        with ShouldRaise(ValueError("'foo' is not a valid method name")):
+            OurMethodFilter(self.called,['foo'])
         
     
 from xlutils.filter import Echo
@@ -563,7 +565,6 @@ class TestErrorFilter(TestCase):
         r = TestReader(
             ('Sheet',[[(XL_CELL_BOOLEAN,True)]]),
             )
-        book = tuple(r.get_workbooks())[0][0]
         # fire methods on filter
         f = ErrorFilter()
         c = Mock()
@@ -705,7 +706,6 @@ class TestColumnTrimmer(TestCase):
     @log_capture()
     def test_multiple_books(self,h):
         r = GlobReader(os.path.join(test_files,'test*.xls'))
-        book = tuple(r.get_workbooks())[0][0]
         # fire methods on filter
         f = ColumnTrimmer()
         f.next = c = Mock()
@@ -861,7 +861,10 @@ class TestBaseWriter(TestCase):
                 aa = getattr(a,name)
                 self.assertEqual(aa,ea,'%s: %r(actual)!=%r(expected)'%(name,aa,ea))
 
-        assertEqual(e,a,overrides,'book','nsheets')
+        assertEqual(e, a, overrides, 'book',
+                    'nsheets',
+                    'datemode')
+        
         for sheet_x in range(a.nsheets):
             ash = a.sheet_by_index(sheet_x)
             es = e.sheet_by_index(sheet_x)
@@ -1052,12 +1055,32 @@ class TestBaseWriter(TestCase):
         self.failUnless('testall.xls' in w.closed)
         self.check_file(w,test_xls_path)
 
+    def test_dates(self):
+        # create test reader
+        xls_path = os.path.join(test_files, 'date.xls')
+        r = GlobReader(xls_path)
+        # source book must be in weird date mode
+        book = tuple(r.get_workbooks())[0][0]
+        self.assertEqual(book.datemode, 1)
+        # send straight to writer
+        w = TestWriter()
+        r(w)
+        self.check_file(w, xls_path,
+                        # date.xls is fewer sheets and styles than the default
+                        l_a_xf_list=19,
+                        l_e_xf_list=65,
+                        l_e_format_map=74,
+                        l_a_font_list=7,
+                        l_e_font_list=25,
+                        # dates.xls had a standardwidth record but xlwt can't
+                        # currently write these :-/
+                        sheet=dict(standardwidth=None),)
+
     def test_single_workbook_no_formatting(self):
         # create test reader
         test_xls_path = os.path.join(test_files,'testnoformatting.xls')
         r = XLRDReader(open_workbook(os.path.join(test_files,'testall.xls')),'testnoformatting.xls')
         # source sheet must have merged cells for test!
-        book = tuple(r.get_workbooks())[0][0]
         # send straight to writer
         w = TestWriter()
         r(w)
@@ -1158,28 +1181,27 @@ class TestBaseWriter(TestCase):
             ('sheet',([['S1R0C0']]),),
             ('Sheet',([['S2R0C0']]),),
             )
-        book = tuple(r.get_workbooks())[0][0]
         # fire methods on writer
-        should_raise(r,ValueError(
+        with ShouldRaise(ValueError(
             "A sheet named 'sheet' has already been added!"
-            ))(TestWriter())
+            )):
+            r(TestWriter())
     
     def test_empty_sheet_name(self):
         r = TestReader(
             ('',([['S1R0C0']]),),
             )
-        book = tuple(r.get_workbooks())[0][0]
         # fire methods on writer
-        should_raise(r,ValueError(
+        with ShouldRaise(ValueError(
             'Empty sheet name will result in invalid Excel file!'
-            ))(TestWriter())
+            )):
+            r(TestWriter())
     
     def test_max_length_sheet_name(self):
         name = 'X'*31
         r = TestReader(
             (name,([['S1R0C0']]),),
             )
-        book = tuple(r.get_workbooks())[0][0]
         w = TestWriter()
         r(w)
         self.assertEqual(w.files.keys(),['test.xls'])
@@ -1245,18 +1267,17 @@ class TestBaseWriter(TestCase):
         r = TestReader(
             ('X'*32,([['S1R0C0']]),),
             )
-        book = tuple(r.get_workbooks())[0][0]
         # fire methods on writer
-        should_raise(r,ValueError(
+        with ShouldRaise(ValueError(
             'Sheet name cannot be more than 31 characters long, '
             'supplied name was 32 characters long!'
-            ))(TestWriter())
+            )):
+            r(TestWriter())
 
     def test_copy_error_cells(self):
         r = TestReader(
             ('Errors',([[(XL_CELL_ERROR,0)]]),),
             )
-        book = tuple(r.get_workbooks())[0][0]
         w = TestWriter()
         r(w)
         self.assertEqual(w.files.keys(),['test.xls'])
@@ -1269,7 +1290,6 @@ class TestBaseWriter(TestCase):
         r = TestReader(
             ('Bools',([[(XL_CELL_BOOLEAN,True)]]),),
             )
-        book = tuple(r.get_workbooks())[0][0]
         w = TestWriter()
         r(w)
         self.assertEqual(w.files.keys(),['test.xls'])
@@ -1467,7 +1487,8 @@ class TestTestReader(TestCase):
         # NB: when formattng is turned on, an XF will be created at index zero:
         compare(C(XF),book.xf_list[0])
         # ...but no others:
-        should_raise(book.xf_list,IndexError)[42]
+        with ShouldRaise(IndexError):
+            book.xf_list[42]
         # so you'll need to manually create them if you need them.
         # See fixtures.py for examples.
 
